@@ -1,6 +1,6 @@
 package App::logcat_format;
 
-# ABSTRACT: formats adb logcat output 
+# ABSTRACT: pretty print adb logcat output 
 
 use strict;
 use warnings;
@@ -13,9 +13,11 @@ use IO::Async::Process;
 use Getopt::Long::Descriptive;
 use IO::Interactive qw( is_interactive );
 
+=pod
+
 =head1 NAME
 
-App::logcat_format 
+logcat_format - pretty print android adb logcat output
 
 =head1 DESCRIPTION
 
@@ -24,21 +26,25 @@ A tool to pretty print the output of the android sdk 'adb logcat' command.
 =head1 SYNOPSIS
 
 Default adb logcat pretty print ..
+
     % logcat_format 
 
 For default logcat output for emulator only ..
+
     % logcat_format -e 
 
 For default logcat output for device only ..
-    % logcat_format -d 
+
+    % logcat_format -d
 
 For other adb logcat commands, just pipe into logcat_format ..
+
     % adb logcat -v threadtime | logcat_format
     % adb -e logcat -v process | logcat_format
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =cut
 
